/*
 *
 *  This file ist part of the software MonaLisa.
 *  MonaLisa is free software, dependend on non-free software. For more information read LICENCE and README.
 *
 *  (c) Molekulare Bioinformatik, Goethe University Frankfurt, Frankfurt am Main, Germany
 *
 */

package monalisa.addons.netviewer;

import edu.uci.ics.jung.algorithms.layout.GraphElementAccessor;
import edu.uci.ics.jung.algorithms.layout.Layout;
import edu.uci.ics.jung.visualization.Layer;
import edu.uci.ics.jung.visualization.VisualizationViewer;
import edu.uci.ics.jung.visualization.control.PickingGraphMousePlugin;
import edu.uci.ics.jung.visualization.picking.PickedState;
import java.awt.event.MouseEvent;
import java.awt.geom.Point2D;
import java.util.ConcurrentModificationException;

/**
 *
 * @author Jens Einloft
 */
public class MyPickingGraphMousePlugin<V, E> extends PickingGraphMousePlugin {

    private GraphPopupMousePlugin gpmp;
    private MyModalGraphMouse gm;

    public MyPickingGraphMousePlugin(MyModalGraphMouse gm, GraphPopupMousePlugin gpmp) {
        super(16, 17);
        this.gpmp = gpmp;
        this.gm = gm;
    }

    public MyPickingGraphMousePlugin(int selectionModifiers, int addToSelectionModifiers) {
        super(selectionModifiers, addToSelectionModifiers);
    }

    @Override
    public void mousePressed(MouseEvent e) {
        this.down = e.getPoint();
        VisualizationViewer vv = (VisualizationViewer) e.getSource();
        GraphElementAccessor pickSupport = vv.getPickSupport();
        PickedState pickedVertexState = vv.getPickedVertexState();
        PickedState pickedEdgeState = vv.getPickedEdgeState();
        if ((pickSupport != null) && (pickedVertexState != null)) {
            Layout layout = vv.getGraphLayout();
            if (e.getModifiers() == this.modifiers) {
                this.rect.setFrameFromDiagonal(this.down, this.down);

                Point2D ip = e.getPoint();

                this.vertex = pickSupport.getVertex(layout, ip.getX(), ip.getY());
                if (this.vertex != null) {
                    if(!pickedVertexState.isPicked(this.vertex)) {
                        pickedVertexState.clear();
                        pickedVertexState.pick(this.vertex, true);
                    }                  
   
                    Point2D q = (Point2D) layout.transform(this.vertex);
                    Point2D gp = vv.getRenderContext().getMultiLayerTransformer().inverseTransform(Layer.LAYOUT, ip);
                    this.offsetx = (float) (gp.getX() - q.getX());
                    this.offsety = (float) (gp.getY() - q.getY());                    
                } else if((this.edge = pickSupport.getEdge(layout, ip.getX(), ip.getY())) != null) {
                    pickedEdgeState.clear();
                    pickedEdgeState.pick(edge, true);
                    if(((NetViewerEdge)edge).getMasterEdge().getBendEdges().size() > 0 && gpmp.getMouseMode().equalsIgnoreCase(GraphPopupMousePlugin.NORMAL))
                        try  {
                            for(NetViewerEdge nvEdge : ((NetViewerEdge)edge).getMasterEdge().getBendEdges())
                                pickedEdgeState.pick(nvEdge, true);
                        }
                        catch(ConcurrentModificationException cme) { }
                    else
                        pickedEdgeState.pick(edge, true);
                } else {
                    vv.addPostRenderPaintable(this.lensPaintable);
                    pickedEdgeState.clear();
                    pickedVertexState.clear();
                }
            } else if (e.getModifiers() == this.addToSelectionModifiers) {
                vv.addPostRenderPaintable(this.lensPaintable);
                this.rect.setFrameFromDiagonal(this.down, this.down);
                Point2D ip = e.getPoint();
                this.vertex = pickSupport.getVertex(layout, ip.getX(), ip.getY());
                if (this.vertex != null) {
                    boolean wasThere = pickedVertexState.pick(this.vertex, !pickedVertexState.isPicked(this.vertex));
                    if (wasThere) {
                        this.vertex = null;
                    } else {
                        Point2D q = (Point2D) layout.transform(this.vertex);
                        Point2D gp = vv.getRenderContext().getMultiLayerTransformer().inverseTransform(Layer.LAYOUT, ip);
                        this.offsetx = (float) (gp.getX() - q.getX());
                        this.offsety = (float) (gp.getY() - q.getY());
                    }
                } else if ((this.edge = pickSupport.getEdge(layout, ip.getX(), ip.getY())) != null) {
                    pickedEdgeState.pick(this.edge, !pickedEdgeState.isPicked(this.edge));
                }
            }
        }
        if (this.vertex != null) {
            e.consume();
        }
    }
    
}
