/*
 *
 *  This file ist part of the software MonaLisa.
 *  MonaLisa is free software, dependend on non-free software. For more information read LICENCE and README.
 *
 *  (c) Molekulare Bioinformatik, Goethe University Frankfurt, Frankfurt am Main, Germany
 *
 */

package monalisa.addons.netviewer;

import edu.uci.ics.jung.visualization.Layer;
import edu.uci.ics.jung.visualization.VisualizationViewer;
import edu.uci.ics.jung.visualization.control.AbstractPopupGraphMousePlugin;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.geom.Point2D;
import java.util.ArrayList;
import java.util.List;
import javax.swing.AbstractAction;
import javax.swing.JList;
import javax.swing.JMenu;
import javax.swing.JPopupMenu;
import monalisa.resources.ResourceManager;
import monalisa.resources.StringResources;

/**
 * Context menu for SearchBar
 * @author Jens Einloft
 */
public class SearchBarPopupMousePlugin extends AbstractPopupGraphMousePlugin implements MouseListener {

    private static final ResourceManager resources = ResourceManager.instance();
    private static final StringResources strings = resources.getDefaultStrings();

    private NetViewer nv;
    private VisualizationViewer<NetViewerNode, NetViewerEdge> vv;
    private JList owner;
    private String type;

    public SearchBarPopupMousePlugin(NetViewer nv, JList owner) {
        this.nv = nv;
        this.vv = nv.vv;
        this.owner = owner;
        type = owner.getName();
    }

    @Override
    protected void handlePopup(final MouseEvent me) {
        JPopupMenu popup = new JPopupMenu();
        final Object[] selectedValues = owner.getSelectedValues();
        String menuName = null;

        // Places + Tansitions
        if(selectedValues.length == 1) {
            final NetViewerNode nvNode = (NetViewerNode) selectedValues[0];

            // Logical places
            if(nvNode.getLogicalPlaces().size() > 1) {
                JMenu zoomAtChildMenu = new JMenu(strings.get("NVZoomAtVertex"));
                int i = 1;
                for(final NetViewerNode n : nvNode.getLogicalPlaces()) {
                    zoomAtChildMenu.add(new AbstractAction(strings.get("NVZoomAtVertex")+" child "+(i++)) {
                        @Override
                        public void actionPerformed(ActionEvent e) {
                            nv.center();
                            Dimension d = vv.getSize();
                            Point2D viewCenter = new Point2D.Float(d.width/2,d.height/2);
                            Point2D nodePosition = vv.getModel().getGraphLayout().transform(n);
                            viewCenter = vv.getRenderContext().getMultiLayerTransformer().inverseTransform(viewCenter);
                            double xdist = viewCenter.getX() - nodePosition.getX();
                            double ydist = viewCenter.getY() - nodePosition.getY();
                            vv.getRenderContext().getMultiLayerTransformer().getTransformer(Layer.LAYOUT).translate(xdist, ydist);
                        }
                    });
                }
                popup.add(zoomAtChildMenu);
            }
            // Non-logical place or transition
            else {
                popup.add(new AbstractAction(strings.get("NVZoomAtVertex")) {
                    @Override
                    public void actionPerformed(ActionEvent e) {
                        nv.center();
                        Dimension d = vv.getSize();
                        Point2D viewCenter = new Point2D.Float(d.width/2,d.height/2);
                        Point2D nodePosition = vv.getModel().getGraphLayout().transform(nvNode);
                        viewCenter = vv.getRenderContext().getMultiLayerTransformer().inverseTransform(viewCenter);
                        double xdist = viewCenter.getX() - nodePosition.getX();
                        double ydist = viewCenter.getY() - nodePosition.getY();
                        vv.getRenderContext().getMultiLayerTransformer().getTransformer(Layer.LAYOUT).translate(xdist, ydist);
                    }
                });
            }

            popup.add(new AbstractAction(strings.get("NVProperties")) {
                @Override
                public void actionPerformed(ActionEvent e) {
                    nv.showVertexSetup(nvNode, me.getX(), me.getY());
                }
            });

        }

        // Only for places
        if(type.equalsIgnoreCase(NetViewer.PLACE)) {

            if(selectedValues.length == 1) {
                NetViewerNode nvNode = (NetViewerNode) selectedValues[0];

                if(nvNode.getLogicalPlaces().size() > 1) {
                    popup.add(new AbstractAction(strings.get("NVMeltAllLogicalPlaces")) {
                        @Override
                        public void actionPerformed(ActionEvent e) {
                            List<NetViewerNode> pickedVerticesList = new ArrayList<NetViewerNode>();
                            for(NetViewerNode n : vv.getRenderContext().getPickedVertexState().getPicked())
                                pickedVerticesList.add(n);
                            nv.removeLogicalPlaces(pickedVerticesList);
                        }
                    });
                }

            }
        }

        // only transitions
        if (type.equalsIgnoreCase(NetViewer.TRANSITION)) {

            if (selectedValues.length == 1) {
                final NetViewerNode nvNode = (NetViewerNode) selectedValues[0];

                popup.add(new AbstractAction(strings.get("NVReverseTransition")) {
                    @Override
                    public void actionPerformed(ActionEvent e) {
                        nv.createReverseTransition(nvNode, me.getX(), me.getY());
                    }
                });
            }
        }

        // Melting places / transitions
        if(selectedValues.length > 1) {
            if(type.equalsIgnoreCase(NetViewer.TRANSITION))
                menuName = strings.get("NVMeltingTransitions");
            else if(type.equalsIgnoreCase(NetViewer.PLACE))
                menuName = strings.get("NVMeltingPlaces");

            popup.add(new AbstractAction(menuName) {
                @Override
                public void actionPerformed(ActionEvent e) {
                    if(type.equalsIgnoreCase(NetViewer.PLACE))
                        nv.meltPlaces();
                    else if(type.equalsIgnoreCase(NetViewer.TRANSITION))
                        nv.meltTransitions();
                }
            });

            popup.add(new AbstractAction(strings.get("NVProperties")) {
                @Override
                public void actionPerformed(ActionEvent e) {
                    List<NetViewerNode> selectedNodes = new ArrayList<NetViewerNode>();
                    for(Object o : selectedValues)
                        selectedNodes.add((NetViewerNode) o);
                    nv.showVertexSetup(selectedNodes, me.getX(), me.getY());
                }
            });
        }

        popup.show(owner, me.getX(), me.getY());
    }
}
