/*
 *
 *  This file ist part of the software MonaLisa.
 *  MonaLisa is free software, dependend on non-free software. For more information read LICENCE and README.
 *
 *  (c) Molekulare Bioinformatik, Goethe University Frankfurt, Frankfurt am Main, Germany
 *
 */

/*
 * ToolBarFrame.java
 *
 * Created on Apr 17, 2012, 2:05:39 PM
 */

package monalisa.addons.netviewer;


import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Point;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import monalisa.addons.netviewer.NetViewer.MctsItemListener;
import monalisa.addons.netviewer.NetViewer.PinvItemListener;
import monalisa.addons.netviewer.NetViewer.TinvItemListener;
import monalisa.resources.ResourceManager;
import monalisa.resources.StringResources;

/**
 * ToolBarFrame for the NetViewer
 * @author Jens Einloft
 */
public class ToolBarFrame extends javax.swing.JFrame {
    private static final long serialVersionUID = 888496283326663308L;
    
    int lastValue;
    boolean blockSpinner;
    
    /** Creates new form ToolBarFrame */
    public ToolBarFrame(final NetViewer netViewer, NetViewerKeyListener nvkl, Map<String, Color> colorMap) {
        this.netViewer = netViewer;
        this.nvkl = nvkl;
        this.colorMap = colorMap;
        
        this.lastValue = 100;       
        this.blockSpinner = false;
        
        this.addKeyListener(nvkl);
        initComponents();                                    
    }
        
    public void setZoomSpinnerValue(int value) {
        this.blockSpinner = true;
        zoomSpinner.setValue(value);
        lastValue = value;
        this.blockSpinner = false;
    }
    
    // Reset the location of the menu
    @Override
    public void setVisible(boolean b) {
        super.setVisible(b);

        if(b) {
            try {
                Dimension screen = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
                Point screenPoint = netViewer.getLocationOnScreen();
                Point menuFramePoint = new Point((int)netViewer.getWidth(), (int)screenPoint.getY());

                if((int)screen.getWidth() > menuFramePoint.getX())
                    this.setLocation(menuFramePoint);
                else
                    this.setLocationRelativeTo(netViewer);
            } catch(Exception e) {
                
            }
        }
    }

     /**
     * Add a new Tab to the Menu Bar of the NetViewer
     * @param name The name of the tab, shown in the header of the tab
     * @param tab The Component which is shown in the Tab. (Panel or ToolBar). Please use a TableLayout.
     */
    public void addTabToMenuBar(String name, Component tab) {
        this.menuPane.addTab(name, tab);
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        sp = new javax.swing.JScrollPane();
        menuPane = new javax.swing.JTabbedPane();
        controlPane = new javax.swing.JPanel();
        controlButtonPanel = new javax.swing.JPanel();
        enableHighlightingButton = new javax.swing.JButton();
        enableLabelsButton = new javax.swing.JButton();
        saveImageButton = new javax.swing.JButton();
        undoButton = new javax.swing.JButton();
        zoomLabel = new javax.swing.JLabel();
        zoomSpinner = new javax.swing.JSpinner();
        addPlacePanel = new javax.swing.JPanel();
        addPlaceButton = new javax.swing.JButton();
        addTransitionPanel = new javax.swing.JPanel();
        addTransitionButton = new javax.swing.JButton();
        addEdgePanel = new javax.swing.JPanel();
        addEdgeButton = new javax.swing.JButton();
        deletePanel = new javax.swing.JPanel();
        deleteButton = new javax.swing.JButton();
        removeBendPanel = new javax.swing.JPanel();
        removeBendButton = new javax.swing.JButton();
        addBendPanel = new javax.swing.JPanel();
        addBendButton = new javax.swing.JButton();
        inEdgePanel = new javax.swing.JPanel();
        inEdgeButton = new javax.swing.JButton();
        outEdgePanel = new javax.swing.JPanel();
        outEdgeButton = new javax.swing.JButton();
        allignYPanel = new javax.swing.JPanel();
        allignYButton = new javax.swing.JButton();
        allignXPanel = new javax.swing.JPanel();
        allignXButton = new javax.swing.JButton();
        mousePickingPanel = new javax.swing.JPanel();
        mousePickingButton = new javax.swing.JButton();
        mouseTransformingPanel = new javax.swing.JPanel();
        mouseTransformingButton = new javax.swing.JButton();
        styleButtonPanel = new javax.swing.JPanel();
        fontSizeLabel = new javax.swing.JLabel();
        iconSizeLabel = new javax.swing.JLabel();
        arrowSizeLabel = new javax.swing.JLabel();
        edgeSizeLabel = new javax.swing.JLabel();
        fontSizeSpinner = new javax.swing.JSpinner();
        iconSizeSpinner = new javax.swing.JSpinner();
        arrowSizeSpinner = new javax.swing.JSpinner();
        edgeSizeSpinner = new javax.swing.JSpinner();
        viewsButtonPanel = new javax.swing.JPanel();
        viewsCb = new javax.swing.JComboBox();
        viewsLabel = new javax.swing.JLabel();
        saveViewButton = new javax.swing.JButton();
        deleteViewButton = new javax.swing.JButton();
        editViewButton = new javax.swing.JButton();
        newViewButton = new javax.swing.JButton();
        exportViewButton = new javax.swing.JButton();
        importViewButton = new javax.swing.JButton();
        jPanel1 = new javax.swing.JPanel();
        analysisPane = new javax.swing.JPanel();
        tinvPanel = new javax.swing.JPanel();
        emLabel = new javax.swing.JLabel();
        allEM = new javax.swing.JLabel();
        allInvCb = new javax.swing.JComboBox();
        trivialInvCb = new javax.swing.JComboBox();
        trivialEM = new javax.swing.JLabel();
        ioEM = new javax.swing.JLabel();
        ioInvCb = new javax.swing.JComboBox();
        inputInvCb = new javax.swing.JComboBox();
        inputEM = new javax.swing.JLabel();
        outputEM = new javax.swing.JLabel();
        cylicEM = new javax.swing.JLabel();
        cyclicInvCb = new javax.swing.JComboBox();
        heatmapButton = new javax.swing.JButton();
        stackTinvs = new javax.swing.JCheckBox();
        manuellColorSelection = new javax.swing.JCheckBox();
        outputInvCb = new javax.swing.JComboBox();
        pinvLabel = new javax.swing.JLabel();
        pinvCb = new javax.swing.JComboBox();
        mctsLabel = new javax.swing.JLabel();
        mctsCb = new javax.swing.JComboBox();

        setTitle("ToolBar");
        setIconImage(resources.getImage("icon-16.png"));
        setMinimumSize(new java.awt.Dimension(250, 550));
        setName("ToolBarFrame"); // NOI18N

        sp.setPreferredSize(new java.awt.Dimension(290, 540));
        sp.addKeyListener(nvkl);

        menuPane.setPreferredSize(new java.awt.Dimension(290, 540));
        menuPane.addKeyListener(nvkl);

        controlPane.setSize(new java.awt.Dimension(350, 512));
        controlPane.setPreferredSize(new java.awt.Dimension(350, 512));
        controlPane.addKeyListener(nvkl);
        controlPane.setLayout(new java.awt.GridBagLayout());

        controlButtonPanel.setLayout(new java.awt.GridBagLayout());

        enableHighlightingButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/icon-16.png"))); // NOI18N
        enableHighlightingButton.setToolTipText(strings.get("NVHideColor"));
        enableHighlightingButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                enableHighlightingButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        controlButtonPanel.add(enableHighlightingButton, gridBagConstraints);

        enableLabelsButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/hide_labels.png"))); // NOI18N
        enableLabelsButton.setToolTipText(strings.get("NVShowAllLabels"));
        enableLabelsButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                enableLabelsButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 0, 5);
        controlButtonPanel.add(enableLabelsButton, gridBagConstraints);

        saveImageButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/save_picture.png"))); // NOI18N
        saveImageButton.setToolTipText(strings.get("NVMakePicButton"));
        saveImageButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                saveImageButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 0, 5);
        controlButtonPanel.add(saveImageButton, gridBagConstraints);

        undoButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/undo.png"))); // NOI18N
        undoButton.setToolTipText(strings.get("NVUndoButton"));
        undoButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                undoButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 0, 5);
        controlButtonPanel.add(undoButton, gridBagConstraints);

        zoomLabel.setFont(new java.awt.Font("Cantarell", 0, 13)); // NOI18N
        zoomLabel.setText("Zoom: ");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(10, 0, 5, 0);
        controlButtonPanel.add(zoomLabel, gridBagConstraints);

        zoomSpinner.setModel(new SpinnerNumberModel(100, 1, 6000, 1));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(10, 0, 5, 0);
        controlButtonPanel.add(zoomSpinner, gridBagConstraints);
        zoomSpinner.addChangeListener(new ChangeListener() {
            int value, inOrOut;
            @Override
            public void stateChanged(ChangeEvent e) {
                if(!blockSpinner) {
                    value = (Integer)zoomSpinner.getValue();
                    inOrOut = (value >= lastValue) ? 1 : -1;
                    netViewer.zommToValue(inOrOut);
                }
            }
        });
        zoomSpinner.setEditor(new JSpinner.NumberEditor(zoomSpinner, "0'%'"));

        addPlacePanel.setLayout(new java.awt.GridBagLayout());

        addPlaceButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/place.png"))); // NOI18N
        addPlaceButton.setToolTipText(strings.get("NVCreateVertex"));
        addPlaceButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                addPlaceButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        addPlacePanel.add(addPlaceButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 5, 5);
        controlButtonPanel.add(addPlacePanel, gridBagConstraints);

        addTransitionPanel.setLayout(new java.awt.GridBagLayout());

        addTransitionButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/transition.png"))); // NOI18N
        addTransitionButton.setToolTipText(strings.get("NVTransition"));
        addTransitionButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                addTransitionButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        addTransitionPanel.add(addTransitionButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 5, 5);
        controlButtonPanel.add(addTransitionPanel, gridBagConstraints);

        addEdgePanel.setLayout(new java.awt.GridBagLayout());

        addEdgeButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/add_edge.png"))); // NOI18N
        addEdgeButton.setToolTipText(strings.get("NVCreateEdge"));
        addEdgeButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                addEdgeButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        addEdgePanel.add(addEdgeButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 5, 5);
        controlButtonPanel.add(addEdgePanel, gridBagConstraints);

        deletePanel.setLayout(new java.awt.GridBagLayout());

        deleteButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/rubber.png"))); // NOI18N
        deleteButton.setToolTipText(strings.get("NVDeleteVertex"));
        deleteButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deleteButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        deletePanel.add(deleteButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 5, 0);
        controlButtonPanel.add(deletePanel, gridBagConstraints);

        removeBendPanel.setLayout(new java.awt.GridBagLayout());

        removeBendButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/delete_bend.png"))); // NOI18N
        removeBendButton.setToolTipText(strings.get("NVDeleteBend"));
        removeBendButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                removeBendButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        removeBendPanel.add(removeBendButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 5, 0);
        controlButtonPanel.add(removeBendPanel, gridBagConstraints);

        addBendPanel.setLayout(new java.awt.GridBagLayout());

        addBendButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/add_bend.png"))); // NOI18N
        addBendButton.setToolTipText(strings.get("NVAddBend"));
        addBendButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                addBendButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        addBendPanel.add(addBendButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 5, 5);
        controlButtonPanel.add(addBendPanel, gridBagConstraints);

        inEdgePanel.setLayout(new java.awt.GridBagLayout());

        inEdgeButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/out_node.png"))); // NOI18N
        inEdgeButton.setToolTipText(strings.get("NVInNode"));
        inEdgeButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                inEdgeButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        inEdgePanel.add(inEdgeButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 5, 5);
        controlButtonPanel.add(inEdgePanel, gridBagConstraints);

        outEdgePanel.setLayout(new java.awt.GridBagLayout());

        outEdgeButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/in_node.png"))); // NOI18N
        outEdgeButton.setToolTipText(strings.get("NVOutNode"));
        outEdgeButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                outEdgeButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        outEdgePanel.add(outEdgeButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 5, 5);
        controlButtonPanel.add(outEdgePanel, gridBagConstraints);

        allignYPanel.setLayout(new java.awt.GridBagLayout());

        allignYButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/alignY.png"))); // NOI18N
        allignYButton.setToolTipText(strings.get("NVAlignmentY"));
        allignYButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                allignYButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        allignYPanel.add(allignYButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 5, 5);
        controlButtonPanel.add(allignYPanel, gridBagConstraints);

        allignXPanel.setLayout(new java.awt.GridBagLayout());

        allignXButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/alignX.png"))); // NOI18N
        allignXButton.setToolTipText(strings.get("NVAlignmentX"));
        allignXButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                allignXButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        allignXPanel.add(allignXButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 5, 5);
        controlButtonPanel.add(allignXPanel, gridBagConstraints);

        mousePickingPanel.setLayout(new java.awt.GridBagLayout());

        mousePickingButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/mouse_picking.png"))); // NOI18N
        mousePickingButton.setToolTipText(strings.get("NVGMPicking"));
        mousePickingButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                mousePickingButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        mousePickingPanel.add(mousePickingButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 5, 5);
        controlButtonPanel.add(mousePickingPanel, gridBagConstraints);

        mouseTransformingPanel.setLayout(new java.awt.GridBagLayout());

        mouseTransformingButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/mouse_transforming.png"))); // NOI18N
        mouseTransformingButton.setToolTipText(strings.get("NVGMTransforming"));
        mouseTransformingButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                mouseTransformingButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
        mouseTransformingPanel.add(mouseTransformingButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 5, 0);
        controlButtonPanel.add(mouseTransformingPanel, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        controlPane.add(controlButtonPanel, gridBagConstraints);

        styleButtonPanel.setLayout(new java.awt.GridBagLayout());

        fontSizeLabel.setFont(new java.awt.Font("Cantarell", 0, 13)); // NOI18N
        fontSizeLabel.setText("Font size:");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(5, 5, 0, 5);
        styleButtonPanel.add(fontSizeLabel, gridBagConstraints);

        iconSizeLabel.setFont(new java.awt.Font("Cantarell", 0, 13)); // NOI18N
        iconSizeLabel.setText("Icon size:");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.insets = new java.awt.Insets(0, 5, 0, 5);
        styleButtonPanel.add(iconSizeLabel, gridBagConstraints);

        arrowSizeLabel.setFont(new java.awt.Font("Cantarell", 0, 13)); // NOI18N
        arrowSizeLabel.setText("Arrow size:");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.insets = new java.awt.Insets(0, 5, 0, 5);
        styleButtonPanel.add(arrowSizeLabel, gridBagConstraints);

        edgeSizeLabel.setFont(new java.awt.Font("Cantarell", 0, 13)); // NOI18N
        edgeSizeLabel.setText("Edge size:");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.insets = new java.awt.Insets(0, 5, 4, 5);
        styleButtonPanel.add(edgeSizeLabel, gridBagConstraints);

        fontSizeSpinner.setModel(new SpinnerNumberModel(12, 5, 100, 1));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 5);
        styleButtonPanel.add(fontSizeSpinner, gridBagConstraints);
        fontSizeSpinner.addChangeListener(new ChangeListener() {
            @Override
            public void stateChanged(ChangeEvent e) {
                netViewer.setFontSize(((Integer)fontSizeSpinner.getValue()).intValue());
            }
        });

        iconSizeSpinner.setModel(new SpinnerNumberModel(12, 5, 150, 1));
        iconSizeSpinner.addChangeListener(new ChangeListener() {
            @Override
            public void stateChanged(ChangeEvent e) {
                netViewer.setIconSize(((Integer)iconSizeSpinner.getValue()).intValue());
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 5);
        styleButtonPanel.add(iconSizeSpinner, gridBagConstraints);

        arrowSizeSpinner.setModel(new SpinnerNumberModel(1.0, 1.0, 100.0, 0.5));
        arrowSizeSpinner.addChangeListener(new ChangeListener() {
            @Override
            public void stateChanged(ChangeEvent e) {
                netViewer.setArrowSize(((Double)arrowSizeSpinner.getValue()).doubleValue());
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 5);
        styleButtonPanel.add(arrowSizeSpinner, gridBagConstraints);

        edgeSizeSpinner.setModel(new SpinnerNumberModel(1, 1, 100, 1));
        edgeSizeSpinner.addChangeListener(new ChangeListener() {
            @Override
            public void stateChanged(ChangeEvent e) {
                netViewer.setEdgeSize(((Integer)edgeSizeSpinner.getValue()).intValue());
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 5);
        styleButtonPanel.add(edgeSizeSpinner, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(15, 0, 0, 0);
        controlPane.add(styleButtonPanel, gridBagConstraints);

        viewsButtonPanel.setLayout(new java.awt.GridBagLayout());

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.gridwidth = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 0);
        viewsButtonPanel.add(viewsCb, gridBagConstraints);

        viewsLabel.setFont(new java.awt.Font("Cantarell", 0, 13)); // NOI18N
        viewsLabel.setText("Views:");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.gridwidth = 6;
        viewsButtonPanel.add(viewsLabel, gridBagConstraints);

        saveViewButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/save_project.png"))); // NOI18N
        saveViewButton.setToolTipText(strings.get("NVSaveAsLayoutMenu"));
        saveViewButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                saveViewButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 5);
        viewsButtonPanel.add(saveViewButton, gridBagConstraints);

        deleteViewButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/delete.png"))); // NOI18N
        deleteViewButton.setToolTipText(strings.get("NVDeleteView"));
        deleteViewButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deleteViewButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 5;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 0);
        viewsButtonPanel.add(deleteViewButton, gridBagConstraints);

        editViewButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/edit.png"))); // NOI18N
        editViewButton.setToolTipText(strings.get("NVEditView"));
        editViewButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                editViewButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 4;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 5);
        viewsButtonPanel.add(editViewButton, gridBagConstraints);

        newViewButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/new_project.png"))); // NOI18N
        newViewButton.setToolTipText(strings.get("NVSaveLayoutMenu"));
        newViewButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                newViewButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.gridwidth = 3;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 5);
        viewsButtonPanel.add(newViewButton, gridBagConstraints);

        exportViewButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/export.png"))); // NOI18N
        exportViewButton.setToolTipText(strings.get("NVExportLayout"));
        exportViewButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                exportViewButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 4;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 0);
        viewsButtonPanel.add(exportViewButton, gridBagConstraints);

        importViewButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/import.png"))); // NOI18N
        importViewButton.setToolTipText(strings.get("NVImportLayout"));
        importViewButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                importViewButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.gridwidth = 3;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 5);
        viewsButtonPanel.add(importViewButton, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(15, 0, 0, 0);
        controlPane.add(viewsButtonPanel, gridBagConstraints);

        javax.swing.GroupLayout jPanel1Layout = new javax.swing.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 0, Short.MAX_VALUE)
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 0, Short.MAX_VALUE)
        );

        controlPane.add(jPanel1, new java.awt.GridBagConstraints());

        menuPane.addTab("Control", controlPane);

        analysisPane.addKeyListener(nvkl);
        analysisPane.setLayout(new java.awt.GridBagLayout());

        tinvPanel.setPreferredSize(new java.awt.Dimension(317, 450));
        tinvPanel.setLayout(new java.awt.GridBagLayout());

        emLabel.setFont(new java.awt.Font("Cantarell", 1, 15)); // NOI18N
        emLabel.setText("Elementary Modes");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 3, 0);
        tinvPanel.add(emLabel, gridBagConstraints);

        allEM.setText("all:");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 2, 0, 0);
        tinvPanel.add(allEM, gridBagConstraints);

        allInvCb.addItemListener(new TinvItemListener(this.netViewer, allInvCb, true, colorMap.get("tinvColor")));
        allInvCb.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                allInvCbActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 2, 0, 0);
        tinvPanel.add(allInvCb, gridBagConstraints);

        trivialInvCb.addItemListener(new TinvItemListener(this.netViewer, trivialInvCb, true, colorMap.get("tinvColor")));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 2, 0, 0);
        tinvPanel.add(trivialInvCb, gridBagConstraints);

        trivialEM.setText("trivial:");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 2, 0, 0);
        tinvPanel.add(trivialEM, gridBagConstraints);

        ioEM.setText("I / O:");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 2, 0, 0);
        tinvPanel.add(ioEM, gridBagConstraints);

        ioInvCb.addItemListener(new TinvItemListener(this.netViewer, ioInvCb, true, colorMap.get("tinvColor")));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 2, 0, 0);
        tinvPanel.add(ioInvCb, gridBagConstraints);

        inputInvCb.addItemListener(new TinvItemListener(this.netViewer, inputInvCb, true, colorMap.get("tinvColor")));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 2, 0, 0);
        tinvPanel.add(inputInvCb, gridBagConstraints);

        inputEM.setText("Input");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 2, 0, 0);
        tinvPanel.add(inputEM, gridBagConstraints);

        outputEM.setText("Output:");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 2, 0, 0);
        tinvPanel.add(outputEM, gridBagConstraints);

        cylicEM.setText("cyclic:");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 2, 0, 0);
        tinvPanel.add(cylicEM, gridBagConstraints);

        cyclicInvCb.addItemListener(new TinvItemListener(this.netViewer, cyclicInvCb, true, colorMap.get("tinvColor")));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 2, 0, 0);
        tinvPanel.add(cyclicInvCb, gridBagConstraints);

        heatmapButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/monalisa/resources/map_color.png"))); // NOI18N
        heatmapButton.setToolTipText(strings.get("NVHeadMapButtonOff"));
        heatmapButton.setToolTipText(strings.get("NVHeadMapButton"));
        heatmapButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                heatmapButtonActionPerformed(evt);
            }
        });
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.insets = new java.awt.Insets(10, 0, 0, 0);
        tinvPanel.add(heatmapButton, gridBagConstraints);

        stackTinvs.setText("Highlight multiple selections");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 12;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.insets = new java.awt.Insets(10, 0, 0, 0);
        tinvPanel.add(stackTinvs, gridBagConstraints);

        manuellColorSelection.setText("Choose a new color for every selection");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 13;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 0);
        tinvPanel.add(manuellColorSelection, gridBagConstraints);

        outputInvCb.addItemListener(new TinvItemListener(this.netViewer, outputInvCb, true, colorMap.get("tinvColor")));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 2, 0, 0);
        tinvPanel.add(outputInvCb, gridBagConstraints);

        pinvLabel.setFont(new java.awt.Font("Cantarell", 1, 15)); // NOI18N
        pinvLabel.setText("Place Invariants");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 10;
        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
        gridBagConstraints.insets = new java.awt.Insets(15, 0, 0, 0);
        tinvPanel.add(pinvLabel, gridBagConstraints);

        pinvCb.setPreferredSize(new java.awt.Dimension(212, 24));
        pinvCb.addItemListener(new PinvItemListener(this.netViewer, pinvCb, colorMap.get("tinvColor")));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 11;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 0);
        tinvPanel.add(pinvCb, gridBagConstraints);

        mctsLabel.setFont(new java.awt.Font("Cantarell", 1, 15)); // NOI18N
        mctsLabel.setText("MCT Sets");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 8;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.insets = new java.awt.Insets(15, 0, 0, 0);
        tinvPanel.add(mctsLabel, gridBagConstraints);

        mctsCb.setPreferredSize(new java.awt.Dimension(212, 24));
        mctsCb.addItemListener(new MctsItemListener(this.netViewer, mctsCb, colorMap.get("mctsColor")));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 9;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(5, 0, 0, 0);
        tinvPanel.add(mctsCb, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        analysisPane.add(tinvPanel, gridBagConstraints);

        menuPane.addTab("Analysis", analysisPane);

        sp.setViewportView(menuPane);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(sp, javax.swing.GroupLayout.DEFAULT_SIZE, 300, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(sp, javax.swing.GroupLayout.DEFAULT_SIZE, 550, Short.MAX_VALUE)
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

    private void importViewButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_importViewButtonActionPerformed
        try {
            this.netViewer.importView();
        } catch (FileNotFoundException ex) {
            Logger.getLogger(ToolBarFrame.class.getName()).log(Level.SEVERE, null, ex);
        } catch (IOException ex) {
            Logger.getLogger(ToolBarFrame.class.getName()).log(Level.SEVERE, null, ex);
        } catch (ClassNotFoundException ex) {
            Logger.getLogger(ToolBarFrame.class.getName()).log(Level.SEVERE, null, ex);
        }
    }//GEN-LAST:event_importViewButtonActionPerformed

    private void exportViewButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_exportViewButtonActionPerformed
        try {
            this.netViewer.exportView();
        } catch (IOException ex) {
            Logger.getLogger(NetViewer.class.getName()).log(Level.SEVERE, null, ex);
        }
    }//GEN-LAST:event_exportViewButtonActionPerformed

    private void newViewButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_newViewButtonActionPerformed
        try {
            this.netViewer.saveView(false, false);
        } catch (ClassNotFoundException ex) {
            Logger.getLogger(NetViewer.class.getName()).log(Level.SEVERE, null, ex);
        } catch (IOException ex) {
            Logger.getLogger(NetViewer.class.getName()).log(Level.SEVERE, null, ex);
        }
    }//GEN-LAST:event_newViewButtonActionPerformed

    private void editViewButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_editViewButtonActionPerformed
        this.netViewer.showEditView();
    }//GEN-LAST:event_editViewButtonActionPerformed

    private void deleteViewButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deleteViewButtonActionPerformed
        try {
            this.netViewer.deleteView();
        } catch (IOException ex) {
            Logger.getLogger(NetViewer.class.getName()).log(Level.SEVERE, null, ex);
        }
    }//GEN-LAST:event_deleteViewButtonActionPerformed

    private void saveViewButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_saveViewButtonActionPerformed
        try {
            this.netViewer.saveView(false, true);
        } catch (ClassNotFoundException ex) {
            Logger.getLogger(NetViewer.class.getName()).log(Level.SEVERE, null, ex);
        } catch (IOException ex) {
            Logger.getLogger(NetViewer.class.getName()).log(Level.SEVERE, null, ex);
        }
    }//GEN-LAST:event_saveViewButtonActionPerformed

    private void mouseTransformingButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_mouseTransformingButtonActionPerformed
        this.netViewer.changeMouseModeToTransforming();
    }//GEN-LAST:event_mouseTransformingButtonActionPerformed

    private void removeBendButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_removeBendButtonActionPerformed
        this.netViewer.deleteBendMouseAction();
    }//GEN-LAST:event_removeBendButtonActionPerformed

    private void addBendButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addBendButtonActionPerformed
        this.netViewer.addBendMouseAction();
    }//GEN-LAST:event_addBendButtonActionPerformed

    private void mousePickingButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_mousePickingButtonActionPerformed
        this.netViewer.changeMouseModeToPicking();
    }//GEN-LAST:event_mousePickingButtonActionPerformed

    private void allignXButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_allignXButtonActionPerformed
        this.netViewer.alignXMouseAction();
    }//GEN-LAST:event_allignXButtonActionPerformed

    private void inEdgeButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_inEdgeButtonActionPerformed
        this.netViewer.inVertexMouseAction();
    }//GEN-LAST:event_inEdgeButtonActionPerformed

    private void outEdgeButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_outEdgeButtonActionPerformed
        this.netViewer.outVertexMouseAction();
    }//GEN-LAST:event_outEdgeButtonActionPerformed

    private void allignYButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_allignYButtonActionPerformed
        this.netViewer.alignYMouseAction();
    }//GEN-LAST:event_allignYButtonActionPerformed

    private void undoButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_undoButtonActionPerformed
        this.netViewer.undoLastAction();
    }//GEN-LAST:event_undoButtonActionPerformed

    private void saveImageButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_saveImageButtonActionPerformed
        try {
            this.netViewer.makePic();
        } catch (IOException ex) {
            Logger.getLogger(ToolBarFrame.class.getName()).log(Level.SEVERE, null, ex);
        }
    }//GEN-LAST:event_saveImageButtonActionPerformed

    private void enableLabelsButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_enableLabelsButtonActionPerformed
        Boolean value = this.netViewer.showLabels();
        if(value) {
            enableLabelsButton.setIcon(resources.getIcon("hide_labels.png"));
            enableLabelsButton.setToolTipText(strings.get("NVShowAllLabels"));
        } else {
            enableLabelsButton.setIcon(resources.getIcon("show_labels.png"));
            enableLabelsButton.setToolTipText(strings.get("NVHideAllLabels"));
        }
    }//GEN-LAST:event_enableLabelsButtonActionPerformed

    private void enableHighlightingButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_enableHighlightingButtonActionPerformed
        Boolean value = this.netViewer.hideColor();

        if(value) {
            enableHighlightingButton.setIcon(resources.getIcon("sw.png"));
            enableHighlightingButton.setToolTipText(strings.get("NVShowColor"));
        } else {
            enableHighlightingButton.setIcon(resources.getIcon("color.png"));
            enableHighlightingButton.setToolTipText(strings.get("NVHideColor"));
        }
    }//GEN-LAST:event_enableHighlightingButtonActionPerformed

    private void deleteButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deleteButtonActionPerformed
        this.netViewer.deleteMouseAction();
    }//GEN-LAST:event_deleteButtonActionPerformed

    private void addEdgeButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addEdgeButtonActionPerformed
        this.netViewer.edgeMouseAction();
    }//GEN-LAST:event_addEdgeButtonActionPerformed

    private void addTransitionButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addTransitionButtonActionPerformed
        this.netViewer.transitionMouseAction();
    }//GEN-LAST:event_addTransitionButtonActionPerformed

    private void addPlaceButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addPlaceButtonActionPerformed
        this.netViewer.placeMouseAction();
    }//GEN-LAST:event_addPlaceButtonActionPerformed

    private void heatmapButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_heatmapButtonActionPerformed
        if(this.netViewer.heatMap()) {
            heatmapButton.setIcon(resources.getIcon("map_sw.png"));
            heatmapButton.setToolTipText(strings.get("NVHeadMapButtonOff"));
        } else {
            heatmapButton.setIcon(resources.getIcon("map_color.png"));
            heatmapButton.setToolTipText(strings.get("NVHeadMapButtonOn"));
        }
    }//GEN-LAST:event_heatmapButtonActionPerformed

    private void allInvCbActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_allInvCbActionPerformed
        // TODO add your handling code here:
    }//GEN-LAST:event_allInvCbActionPerformed

    // Variables declaration - do not modify//GEN-BEGIN:variables
    protected javax.swing.JButton addBendButton;
    protected javax.swing.JPanel addBendPanel;
    protected javax.swing.JButton addEdgeButton;
    protected javax.swing.JPanel addEdgePanel;
    protected javax.swing.JButton addPlaceButton;
    protected javax.swing.JPanel addPlacePanel;
    protected javax.swing.JButton addTransitionButton;
    protected javax.swing.JPanel addTransitionPanel;
    private javax.swing.JLabel allEM;
    protected javax.swing.JComboBox allInvCb;
    protected javax.swing.JButton allignXButton;
    protected javax.swing.JPanel allignXPanel;
    protected javax.swing.JButton allignYButton;
    protected javax.swing.JPanel allignYPanel;
    private javax.swing.JPanel analysisPane;
    private javax.swing.JLabel arrowSizeLabel;
    private javax.swing.JSpinner arrowSizeSpinner;
    private javax.swing.JPanel controlButtonPanel;
    private javax.swing.JPanel controlPane;
    protected javax.swing.JComboBox cyclicInvCb;
    private javax.swing.JLabel cylicEM;
    protected javax.swing.JButton deleteButton;
    protected javax.swing.JPanel deletePanel;
    protected javax.swing.JButton deleteViewButton;
    private javax.swing.JLabel edgeSizeLabel;
    private javax.swing.JSpinner edgeSizeSpinner;
    protected javax.swing.JButton editViewButton;
    private javax.swing.JLabel emLabel;
    protected javax.swing.JButton enableHighlightingButton;
    protected javax.swing.JButton enableLabelsButton;
    protected javax.swing.JButton exportViewButton;
    private javax.swing.JLabel fontSizeLabel;
    private javax.swing.JSpinner fontSizeSpinner;
    protected javax.swing.JButton heatmapButton;
    private javax.swing.JLabel iconSizeLabel;
    private javax.swing.JSpinner iconSizeSpinner;
    protected javax.swing.JButton importViewButton;
    protected javax.swing.JButton inEdgeButton;
    protected javax.swing.JPanel inEdgePanel;
    private javax.swing.JLabel inputEM;
    protected javax.swing.JComboBox inputInvCb;
    private javax.swing.JLabel ioEM;
    protected javax.swing.JComboBox ioInvCb;
    private javax.swing.JPanel jPanel1;
    protected javax.swing.JCheckBox manuellColorSelection;
    protected javax.swing.JComboBox mctsCb;
    private javax.swing.JLabel mctsLabel;
    protected javax.swing.JTabbedPane menuPane;
    protected javax.swing.JButton mousePickingButton;
    protected javax.swing.JPanel mousePickingPanel;
    protected javax.swing.JButton mouseTransformingButton;
    protected javax.swing.JPanel mouseTransformingPanel;
    protected javax.swing.JButton newViewButton;
    protected javax.swing.JButton outEdgeButton;
    protected javax.swing.JPanel outEdgePanel;
    private javax.swing.JLabel outputEM;
    protected javax.swing.JComboBox outputInvCb;
    protected javax.swing.JComboBox pinvCb;
    private javax.swing.JLabel pinvLabel;
    protected javax.swing.JButton removeBendButton;
    protected javax.swing.JPanel removeBendPanel;
    protected javax.swing.JButton saveImageButton;
    protected javax.swing.JButton saveViewButton;
    private javax.swing.JScrollPane sp;
    protected javax.swing.JCheckBox stackTinvs;
    private javax.swing.JPanel styleButtonPanel;
    private javax.swing.JPanel tinvPanel;
    private javax.swing.JLabel trivialEM;
    protected javax.swing.JComboBox trivialInvCb;
    protected javax.swing.JButton undoButton;
    private javax.swing.JPanel viewsButtonPanel;
    protected javax.swing.JComboBox viewsCb;
    private javax.swing.JLabel viewsLabel;
    protected javax.swing.JLabel zoomLabel;
    protected javax.swing.JSpinner zoomSpinner;
    // End of variables declaration//GEN-END:variables
    
    private static final ResourceManager resources = ResourceManager.instance();
    private static final StringResources strings = resources.getDefaultStrings();

    private NetViewer netViewer;
    private NetViewerKeyListener nvkl;

    private Map<String, Color> colorMap;
}
