/*
 *
 *  This file ist part of the software MonaLisa.
 *  MonaLisa is free software, dependend on non-free software. For more information read LICENCE and README.
 *
 *  (c) Molekulare Bioinformatik, Goethe University Frankfurt, Frankfurt am Main, Germany
 *
 */

package monalisa.gui;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import javax.swing.*;

import java.util.*;

import monalisa.data.pn.Place;
import monalisa.gui.components.SortedListModel;


public class KeggDialog extends JDialog implements ActionListener {

    private static final long serialVersionUID = -2643201072949548550L;
    
    private static final String ACTION_OK = "ACTION_OK";
    private static final String ACTION_CANCEL = "ACTION_CANCEL";
    private static final String IN_ALL = "IN_ALL";
    private static final String OUT_ALL = "OUT_ALL";
    private static final String ALL_IN = "ALL_IN ";
    private static final String ALL_OUT = "ALL_OUT";

    private JScrollPane allScrollPane;
    private JScrollPane inScrollPane;
    private JScrollPane outScrollPane;

    private JList allList = new JList();
    private JList inList = new JList();
    private JList outList = new JList();
    
    private DefaultListModel allListModel = new DefaultListModel();
    private DefaultListModel inListModel = new DefaultListModel();
    private DefaultListModel outListModel = new DefaultListModel();
    
    private SortedListModel sortedAllListModel = new SortedListModel(allListModel);
    private SortedListModel sortedInListModel = new SortedListModel(inListModel);
    private SortedListModel sortedOutListModel = new SortedListModel(outListModel);
    
    private JPanel allInOutPanel = new JPanel();
    private JPanel panel = new JPanel();
    
    private JButton inAllButton;
    private JButton allInButton;
    private JButton outAllButton;
    private JButton allOutButton;
    private JButton okButton;
    private JButton cancelButton;

    private JLabel allLabel;
    private JLabel inLabel;
    private JLabel outLabel;
    
    private Map<String, Place> name2Place = new HashMap<String, Place>();
    private List<Place> input= new ArrayList<Place>();
    private List<Place> output = new ArrayList<Place>();
    
    public KeggDialog(MainDialog owner, Collection<Place> places) {
        super(owner, true);
        for(Place p : places){
            String name = p.<String>getProperty("name");
            allListModel.addElement(name);
            name2Place.put(name, p);
        }
        
        allList = new JList(sortedAllListModel);
        inList = new JList(sortedInListModel);
        outList = new JList(sortedOutListModel);
        initComponents();
        setLocationRelativeTo(owner);
        setVisible(true);
    }
    
    private void initComponents() {
        addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                setVisible(false);
            }
        });
        
        okButton = new JButton("Ok");
        okButton.setActionCommand(ACTION_OK);
        okButton.addActionListener(this);
        
        cancelButton = new JButton("Cancel");
        cancelButton.setActionCommand(ACTION_CANCEL);
        cancelButton.addActionListener(this);
        
        inAllButton = new JButton("»");
        inAllButton.setActionCommand(IN_ALL);
        inAllButton.addActionListener(this);
        
        outAllButton = new JButton("«");
        outAllButton.setActionCommand(OUT_ALL);
        outAllButton.addActionListener(this);
        
        allInButton = new JButton("«");
        allInButton.setActionCommand(ALL_IN);
        allInButton.addActionListener(this);
        
        allOutButton = new JButton("»");
        allOutButton.setActionCommand(ALL_OUT);
        allOutButton.addActionListener(this);
        
        inLabel = new JLabel("Input");
        allLabel = new JLabel("All Places");
        outLabel = new JLabel("Output");
        
        allScrollPane =
            new JScrollPane(allList, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
                JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        allScrollPane.setPreferredSize(new Dimension(150, 200));
        
        inScrollPane =
            new JScrollPane(inList, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
                JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        inScrollPane.setPreferredSize(new Dimension(150, 200));
        
        outScrollPane =
            new JScrollPane(outList, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
                JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        outScrollPane.setPreferredSize(new Dimension(150, 200));
        
       
        GroupLayout allInOutLayout = new GroupLayout(allInOutPanel);
        allInOutPanel.setLayout(allInOutLayout);
        allInOutLayout.setAutoCreateGaps(true);
        allInOutLayout.setAutoCreateContainerGaps(true);
        
        allInOutLayout.setHorizontalGroup(allInOutLayout.createSequentialGroup()
            .addGroup(allInOutLayout.createParallelGroup()
                    .addComponent(inLabel)
                    .addComponent(inScrollPane, 0, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
            .addGroup(allInOutLayout.createParallelGroup()
                .addComponent(allInButton)
                .addComponent(inAllButton))
            .addGroup(allInOutLayout.createParallelGroup()
                    .addComponent(allLabel)
                    .addComponent(allScrollPane, 0, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
            .addGroup(allInOutLayout.createParallelGroup()
                .addComponent(allOutButton)
                .addComponent(outAllButton))
            .addGroup(allInOutLayout.createParallelGroup()
                    .addComponent(outLabel)
                    .addComponent(outScrollPane, 0, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)));
        
        allInOutLayout.setVerticalGroup(allInOutLayout.createSequentialGroup()
            .addGroup(allInOutLayout.createParallelGroup(GroupLayout.Alignment.CENTER)
                .addGroup(allInOutLayout.createSequentialGroup()
                    .addComponent(inLabel)
                    .addComponent(inScrollPane))
                .addGroup(allInOutLayout.createSequentialGroup()
                    .addComponent(allInButton)
                    .addComponent(inAllButton))
                .addGroup(allInOutLayout.createSequentialGroup()
                    .addComponent(allLabel)
                    .addComponent(allScrollPane))
                .addGroup(allInOutLayout.createSequentialGroup()
                    .addComponent(allOutButton)
                    .addComponent(outAllButton))
                .addGroup(allInOutLayout.createSequentialGroup()
                        .addComponent(outLabel)
                        .addComponent(outScrollPane))));
        
        GroupLayout layout = new GroupLayout(panel);
        panel.setLayout(layout);
        layout.setAutoCreateGaps(true);
        layout.setAutoCreateContainerGaps(true);
        
        layout.setHorizontalGroup(layout.createParallelGroup()
                .addComponent(allInOutPanel)
                .addGroup(GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                        .addComponent(cancelButton)
                        .addComponent(okButton)));
        
        layout.setVerticalGroup(layout.createSequentialGroup()
                .addComponent(allInOutPanel)
                .addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE)
                        .addComponent(cancelButton)
                        .addComponent(okButton)));
        
        layout.linkSize(SwingConstants.HORIZONTAL, cancelButton, okButton);
        
        add(panel);
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        pack();
    }
    
    @Override
    public void actionPerformed(ActionEvent e) {
        final String action = e.getActionCommand();
        if (action == ACTION_OK)
            submit();
        else if(action == ACTION_CANCEL){
            setVisible(false);
        }
        else if(action == IN_ALL){
            for(Object o : inList.getSelectedValues()){
                allListModel.addElement(o.toString());
                inListModel.removeElement(o);
            }
        }
        else if(action == OUT_ALL){
            for(Object o : outList.getSelectedValues()){
                allListModel.addElement(o.toString());
                outListModel.removeElement(o);
            }
        }
        else if(action == ALL_IN){
            for(Object o : allList.getSelectedValues()){
                inListModel.addElement(o.toString());
                allListModel.removeElement(o);
            }
        }
        else if(action == ALL_OUT){
            for(Object o : allList.getSelectedValues()){
                outListModel.addElement(o.toString());
                allListModel.removeElement(o);
            }
        }
    }
    
    private void submit(){
        for(int i = 0; i < inListModel.getSize(); i++){
            input.add(name2Place.get(inListModel.get(i).toString()));
        }
        for(int i = 0; i < outListModel.getSize(); i++){
            output.add(name2Place.get(outListModel.get(i).toString()));
        }
        setVisible(false);
    }
    
    public List<Place> inputs(){
        return this.input;
    }
    
    public List<Place> outputs(){
        return this.output;
    }
}
