/*
 *
 *  This file ist part of the software MonaLisa.
 *  MonaLisa is free software, dependend on non-free software. For more information read LICENCE and README.
 *
 *  (c) Molekulare Bioinformatik, Goethe University Frankfurt, Frankfurt am Main, Germany
 *
 */

package monalisa.results;

import java.io.File;
import java.io.IOException;
import java.util.List;

import monalisa.Project;
import monalisa.data.output.DistanceMatrixOutput;
import monalisa.data.pn.TInvariant;

/**
 * Encodes a distance matrix.
 * @author Konrad Rudolph
 *
 */
public final class DistanceMatrix implements Result {
    private static final long serialVersionUID = 2485619479828934741L;

    private final float[][] matrix;
    
    public DistanceMatrix(float[][] matrix, String distanceFunction, List<TInvariant> tinvariants) {
        this.matrix = matrix;
    }
    
    public int size() {
        return matrix.length;
    }
    
    public float get(int x, int y) {
        return matrix[x][y];
    }

    @Override
    public void export(File path, Configuration config, Project project) throws IOException {
        DistanceMatrixOutput output = new DistanceMatrixOutput();
        output.export(this, config, project, path);
    }

    @Override
    public String filenameExtension() {
        return "phylip";
    }
}
