/*
 *
 *  This file ist part of the software MonaLisa.
 *  MonaLisa is free software, dependend on non-free software. For more information read LICENCE and README.
 *
 *  (c) Molekulare Bioinformatik, Goethe University Frankfurt, Frankfurt am Main, Germany
 *
 */

package monalisa.results;

import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.List;
import java.util.Map;

import monalisa.Project;


public final class Knockout implements Result {
    private static final long serialVersionUID = 3512064024064281251L;
    private final Map<List<String>, List<String>> knockouts;
    
    public Knockout(Map<List<String>, List<String>> knockouts) {
        this.knockouts = knockouts;
    }
    
    @Override
    public void export(File path, Configuration config, Project project) throws IOException {
        PrintWriter printer = null;
        try {
            printer = new PrintWriter(path);            

            // Print the table.                       
            printer.println("#Knocked out -> also knocked out");
            String line;
            for(List<String> knockedOut : knockouts.keySet()) {
                line = "";
                int knockedOutSize = knockedOut.size(), i = 0;
                if(knockedOutSize > 1) {
                    for(String name : knockedOut) {
                        line += name.replace(" ", "_");
                        i++;
                        if(i < knockedOutSize)
                           line += " ";
                    }
                }
                else
                    line += (knockedOut.toArray()[0]).toString();
                line += " -> ";
                for(String name : knockouts.get(knockedOut)) {
                    line += name.replace(" ", "_")+" ";
                }
                printer.println(line.substring(0, line.length()-1));
            }
        }
        finally {
            if (printer != null)
                printer.close();
        }
    }

    @Override
    public String filenameExtension() {
        return "txt";
    }
}
