/*
 *
 *  This file ist part of the software MonaLisa.
 *  MonaLisa is free software, dependend on non-free software. For more information read LICENCE and README.
 *
 *  (c) Molekulare Bioinformatik, Goethe University Frankfurt, Frankfurt am Main, Germany
 *
 */

package monalisa.tools.topology;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import monalisa.data.pn.PetriNet;
import monalisa.data.pn.Place;
import monalisa.data.pn.Transition;

public class DegreeDistribution {
    PetriNet pn;
    
    public DegreeDistribution(PetriNet pn) {
        this.pn = pn;
    }

    public String computePlainText() {
        StringBuilder stringBuilder = new StringBuilder();

        stringBuilder.append("#Name|In Arcs|Out Arcs|Sum\n#Species\n");
        for(Place p : pn.places()) {
            stringBuilder.append(p.getProperty("name"));
            stringBuilder.append("|");
            stringBuilder.append(p.inputs().size());
            stringBuilder.append("|");
            stringBuilder.append(p.outputs().size());
            stringBuilder.append("|");
            stringBuilder.append(p.inputs().size()+p.outputs().size());
            stringBuilder.append("\n");
        }

        stringBuilder.append("#Reactions\n");
        for(Transition t : pn.transitions()) {
            stringBuilder.append(t.getProperty("name"));
            stringBuilder.append("|");
            stringBuilder.append(t.inputs().size());
            stringBuilder.append("|");
            stringBuilder.append(t.outputs().size());
            stringBuilder.append("|");
            stringBuilder.append(t.inputs().size()+t.outputs().size());
            stringBuilder.append("\n");
        }

        return stringBuilder.toString();
    }

    public String computeRScript() {
        Map<Integer, Integer> ndPlaces = new HashMap<Integer, Integer>();
        Map<Integer, Integer> ndTransitions = new HashMap<Integer, Integer>();

        Integer count = 0;
        for(Place p : pn.places()) {
            count = 0;

            count += p.inputs().size() + p.outputs().size();
            if(!ndPlaces.containsKey(count))
                ndPlaces.put(count, 0);
            ndPlaces.put(count, ndPlaces.get(count)+1);
        }
        
        List<Integer> listOfPlaceDegrees = new ArrayList<Integer>(ndPlaces.keySet());
        Collections.sort(listOfPlaceDegrees);

        for(Transition t : pn.transitions()) {
            count = 0;

            count += t.inputs().size() + t.outputs().size();
            if(!ndTransitions.containsKey(count))
                ndTransitions.put(count, 0);
            ndTransitions.put(count, ndTransitions.get(count)+1);
        }

        List<Integer> listOfTransitionDegrees = new ArrayList<Integer>(ndTransitions.keySet());        
        Collections.sort(listOfTransitionDegrees);

        double placeNumber = pn.places().size();
        String placesDegree = "placeDegree<-c(";
        String placesProbability = "placeDegreeDistribution<-c(";
        String placeDegreeAbsolute = "placeDegreeAbsolute<-c(";
        for (Integer i : listOfPlaceDegrees) {
            placesDegree = placesDegree.concat(i+", ");
            placesProbability = placesProbability.concat(String.valueOf((double) ndPlaces.get(i) / placeNumber) + ", ");
            placeDegreeAbsolute = placeDegreeAbsolute.concat(String.valueOf( ndPlaces.get(i)) + ", ");
        }        
        placesDegree = placesDegree.substring(0, placesDegree.lastIndexOf(","));
        placesProbability = placesProbability.substring(0, placesProbability.lastIndexOf(","));
        placesDegree = placesDegree.concat(")");
        placesProbability = placesProbability.concat(")");
        placeDegreeAbsolute = placeDegreeAbsolute.substring(0, placeDegreeAbsolute.lastIndexOf(","));
        placeDegreeAbsolute = placeDegreeAbsolute.concat(")");

        double transitionNumber = pn.transitions().size();
        String transitionDegree = "transitionDegree<-c(";
        String transitionProbability = "transitionDegreeDistribution<-c(";
        String transitionDegreeAbsolute = "transitionDegreeAbsolute<-c(";
        for (Integer i : listOfTransitionDegrees) {
            transitionDegree = transitionDegree.concat(i+", ");
            transitionProbability = transitionProbability.concat(String.valueOf((double) ndTransitions.get(i) / transitionNumber) + ", ");
            transitionDegreeAbsolute = transitionDegreeAbsolute.concat(String.valueOf( ndTransitions.get(i)) + ", ");
        }
        transitionDegree = transitionDegree.substring(0, transitionDegree.lastIndexOf(","));
        transitionProbability = transitionProbability.substring(0, transitionProbability.lastIndexOf(","));
        transitionDegree = transitionDegree.concat(")");
        transitionProbability = transitionProbability.concat(")");
        transitionDegreeAbsolute = transitionDegreeAbsolute.substring(0, transitionDegreeAbsolute.lastIndexOf(","));
        transitionDegreeAbsolute = transitionDegreeAbsolute.concat(")");

        String output = placesDegree + "\n" + placesProbability + "\n" + transitionDegree + "\n"+ transitionProbability + "\n"  + placeDegreeAbsolute + "\n" + transitionDegreeAbsolute + "\n" +
                "\nbarplot(100*placeDegreeDistribution, names.arg = placeDegree, xlab = \"node degree\", ylab = \"percent of nodes with this degree\", main=\"Distribution of Node Degrees (Metabolites)\")"
                + "\nbarplot(100*transitionDegreeDistribution, names.arg = transitionDegree, xlab = \"node degree\", ylab = \"percent of nodes with this degree\", main=\"Distribution of Node Degrees (Reactions)\")";
        return output;
    }
}